A package for finding the sin, cos, tan, their inverses, log and if the output answer is in fibonacci series or not

use the commands

sin: .sin()
cos: .cos()
tan: .tan()
inverse of sin: .asin()
inverse of cos: .acos()
inverse of tan: .tan()
log: .log()